@@ -22,6 +22,14 @@
 #include <pan/general/debug.h>
 #include <pan/general/macros.h>
 #include <pan/data/data.h>
+#include <gmime/gmime.h>
+
+//#include <glib/gprintf.h>
+extern "C"
+{
+  #include <glib.h>
+}
+
 #include "article-filter.h"
 
 using namespace pan;
@@ -48,16 +56,19 @@ ArticleFilter :: test_article (const Data        & data,
                                const Quark       & group,
                                const Article     & article) const
 {
+  const ArticleCache & cache(data.get_cache());
   bool pass (false);
   switch (criteria._type)
   {
     case FilterInfo::AGGREGATE_AND:
       pass = true;
       foreach_const (FilterInfo::aggregates_t, criteria._aggregates, it) {
-        if (!test_article (data, *it, group, article)) {
-          pass = false;
-          break;
-        }
+        // assume test passes if test needs body but article not cached
+        if (!it->_needs_body || cache.contains(article.message_id) )
+          if (!test_article (data, *it, group, article)) {
+            pass = false;
+            break;
+          }
       }
       break;
 
@@ -67,10 +78,12 @@ ArticleFilter :: test_article (const Data        & data,
       else {
         pass = false;
         foreach_const (FilterInfo::aggregates_t, criteria._aggregates, it) {
-          if (test_article (data, *it, group, article)) {
-            pass = true;
-            break;
-          }
+          // assume test fails if test needs body but article not cached
+          if (!it->_needs_body || cache.contains(article.message_id) )
+            if (test_article (data, *it, group, article)) {
+              pass = true;
+              break;
+            }
         }
       }
       break;
@@ -118,7 +131,7 @@ ArticleFilter :: test_article (const Data        & data,
         }
         else if (criteria._text._impl_text.find("(.*:){") != std::string::npos) // user is filtering by # of crossposts
         {
-          const char * search = "(.*:){";
+          const char * search = "(.*:){";//}
           std::string::size_type pos = criteria._text._impl_text.find (search) + strlen(search);
           const int ge = atoi (criteria._text._impl_text.c_str() + pos);
           FilterInfo tmp;
@@ -145,7 +158,7 @@ ArticleFilter :: test_article (const Data        & data,
             s += xit->group;
             s += ':';
             char buf[32];
-            snprintf (buf, sizeof(buf), "%lu", xit->number);
+            g_snprintf (buf, sizeof(buf), "%"G_GUINT64_FORMAT, xit->number);
             s += buf;
             s += ' ';
           }
@@ -176,7 +189,24 @@ ArticleFilter :: test_article (const Data        & data,
         pass = criteria._text.test (s);
       }
       else
-        pass = criteria._text.test (get_header(article, criteria._header));
+        if (!criteria._needs_body)
+          pass = criteria._text.test (get_header(article, criteria._header));
+        else
+        {
+          if (cache.contains(article.message_id)) {
+            ArticleCache::mid_sequence_t mid(1, article.message_id);
+#ifdef HAVE_GMIME_CRYPTO
+            GPGDecErr err;
+            GMimeMessage *msg = cache.get_message(mid,err);
+#else
+            GMimeMessage *msg = cache.get_message(mid);
+#endif
+            const char *hdr = g_mime_object_get_header(GMIME_OBJECT(msg), criteria._header);
+            pass = criteria._text.test (hdr);
+            g_object_unref(msg);
+          }
+          else pass = false;
+        }
       break;
 
     case FilterInfo::SCORE_GE:
