@@ -215,7 +215,7 @@ DataImpl :: xover_unref (const Quark& group)
 void
 DataImpl :: set_xover_low (const Quark   & group,
                            const Quark   & server,
-                           const unsigned long   low)
+                           const uint64_t   low)
 {
   ReadGroup::Server * rgs (find_read_group_server (group, server));
   if (rgs != 0)
@@ -242,6 +242,8 @@ DataImpl :: xover_add (const Quark         & server,
     return 0;
   }
 
+//  std::cerr<<"xover add : "<<subject<<" "<<author<<" "<<message_id<<" lines "<<line_count<<" bytes "<<byte_count<<std::endl;
+
   const Article* new_article (0);
   h->_dirty = true;
   XOverEntry& workarea (xover_get_workarea (group));
