@@ -18,7 +18,6 @@
  */
 
 #include <config.h>
-
 #include <cassert>
 #include <cerrno>
 #include <cctype>
@@ -28,21 +27,51 @@ extern "C"
   #include <unistd.h>
   #include <sys/stat.h>
   #include <sys/types.h>
-
   #include <glib.h>
   #include <glib/gi18n.h>
+  #ifndef G_OS_WIN32
+    #include <pwd.h>
+  #endif
 }
 
 #include "debug.h"
 #include "log.h"
 #include "messages.h"
 #include "file-util.h"
+#include "e-util.h"
 #include "utf8-utils.h"
 #include <algorithm>
 
+
+
 using namespace pan;
 
 #define is_nonempty_string(a) ((a) && (*a))
+#define NL std::endl
+
+std::ostream&
+file :: print_file_info (std::ostream& os, const char* file)
+{
+  EvolutionDateMaker dm;
+  struct stat sb;
+  int ret = stat(file,&sb);
+
+  os << "File information for file "<<file<<NL;
+  if (ret)
+  {
+    os << "File not found / accessible!"<<NL;
+    return os;
+  }
+  os << "Umask : "<<sb.st_mode<<NL;
+  os << "User ID : "<< sb.st_uid<<NL;
+  os << "Group ID : "<< sb.st_gid<<NL;
+  os << "Size (Bytes) : "<<sb.st_size<<NL;
+  os << "Last accessed : "<<dm.get_date_string(sb.st_atime)<<NL;
+  os << "Last modified : "<<dm.get_date_string(sb.st_mtime)<<NL;
+  os << "Last status change : "<<dm.get_date_string(sb.st_ctime)<<NL;
+
+  return os;
+}
 
 /***
 ****
@@ -63,8 +92,8 @@ file :: get_pan_home ()
       g_free (pch);
     }
   }
-                                                                                                                                
-  file :: ensure_dir_exists (pan_home);
+
+  ensure_dir_exists (pan_home);
   return pan_home;
 }
 
@@ -75,36 +104,29 @@ file :: pan_strerror (int error_number)
   return pch && *pch ? pch : "";
 }
 
-#if !GLIB_CHECK_VERSION(2,8,0)
-static int
-pan_mkdir (const char * path, gulong mode)
+namespace
 {
-  int retval = 0;
 
-  pan_return_val_if_fail (is_nonempty_string(path), retval);
+  enum EX_ERRORS
+  {
+    EX_NOFILE, EX_BIT, EX_SUCCESS
+  };
 
-  if (strlen(path)==2 && isalpha((guchar)path[0]) && path[1]==':')
+  EX_ERRORS check_executable_bit(const char* d)
   {
-    /* smells like a windows pathname.. skipping */
-  }
-  else
-  {
-    errno = 0;
-#if GLIB_CHECK_VERSION(2,6,0)
-    retval = g_mkdir (path, mode);
-#elif defined(G_OS_WIN32)
-    retval = mkdir (path);
+#ifndef G_OS_WIN32
+    struct stat sb;
+    if (stat (d, &sb) == -1) return EX_NOFILE;
+    const char* user(g_get_user_name());
+    struct passwd* pw(getpwnam(user));
+    if (sb.st_mode & S_IXUSR || ((sb.st_mode & S_IXGRP ) && pw->pw_gid == sb.st_gid))
+      return EX_SUCCESS;
+    return EX_BIT;
 #else
-    retval = mkdir (path, mode);
+    return EX_SUCCESS;
 #endif
-    if (errno == EEXIST)
-      retval = 0;
   }
-	
-  return retval;
 }
-#endif
-
 
 bool
 file :: ensure_dir_exists (const StringView& dirname_sv)
@@ -113,48 +135,27 @@ file :: ensure_dir_exists (const StringView& dirname_sv)
 
   pan_return_val_if_fail (!dirname_sv.empty(), true);
   bool retval (true);
-
   const std::string dirname (dirname_sv.to_string());
+  EX_ERRORS cmd (check_executable_bit(dirname.c_str()));
+  if (cmd == EX_BIT) goto _set_bit;
+
   if (!g_file_test (dirname.c_str(), G_FILE_TEST_IS_DIR))
+    retval = !g_mkdir_with_parents (dirname.c_str(), 0740); // changed from 755
+
+  if (!retval)
   {
-#if GLIB_CHECK_VERSION(2,8,0)
-    retval = !g_mkdir_with_parents (dirname.c_str(), 0755);
-#else
-    const char * in = dirname.c_str();
-    char * buf = g_new (char, dirname.size()+1);
-    char * out = buf;
-
-    *out++ = *in++;
-    for (;;)
-    {
-      if (*in=='\0' || *in==G_DIR_SEPARATOR)
+    // check for executable bit
+    Log::add_err_va("Error creating directory '%s' : %s", dirname.c_str(),
+                    cmd == EX_NOFILE ? "error accessing file." : "executable bit not set.");
+    // set it manually
+    _set_bit:
+    if (cmd == EX_BIT)
+      if (chmod(dirname.c_str(), 0740))
       {
-        *out = '\0';
-
-        if (!g_file_test (buf, G_FILE_TEST_IS_DIR))
-        {
-          Log :: add_info_va (_("Creating directory \"%s\""), buf);
-          if (pan_mkdir (buf, 0755))
-          {
-            Log::add_err_va (_("Couldn't create directory \"%s\": %s"), buf, pan_strerror (errno));
-            retval = FALSE;
-            break;
-          }
-        }
+        Log::add_urgent_va("Error setting executable bit for directory '%s' : "
+                           "Please check your permissions.", dirname.c_str());
       }
-
-      *out = *in;
-      if (!*in)
-        break;
-
-      ++out;
-      ++in;
-    }
-
-    g_free (buf);
-#endif
   }
-
   return retval;
 }
 
@@ -164,6 +165,7 @@ file :: file_exists (const char * filename)
    return filename && *filename && g_file_test (filename, G_FILE_TEST_EXISTS);
 }
 
+
 /**
 *** Attempt to make a filename safe for use.
 *** This is done by replacing illegal characters with '_'.
