@@ -25,16 +25,11 @@
 extern "C" {
   #include <stddef.h>
   #include <stdio.h>
-  #include <glib/gtypes.h>
+  #include <glib.h>
+  #include <glib/gstdio.h>
 }
 #include <pan/general/string-view.h>
 
-#include <glibconfig.h> // get the version number
-#include <glib/gutils.h> // get GLIB_CHECK_VERSION
-#if GLIB_CHECK_VERSION(2,6,0)
-extern "C" {
-  #include <glib/gstdio.h>
-}
 #define g_freopen freopen
 #define g_fopen fopen
 #define g_rmdir rmdir
@@ -44,7 +39,6 @@ extern "C" {
 #define g_stat stat
 #define g_rename rename
 #define g_open open
-#endif
 
 namespace pan
 {
@@ -55,6 +49,9 @@ namespace pan
    */
   namespace file
   {
+    /** Stats a file and prints out some useful info. Umask etc.... */
+    std::ostream& print_file_info (std::ostream&, const char*);
+
     /** just like strerror but never returns NULL */
     const char * pan_strerror (int error_number);
 
@@ -82,6 +79,8 @@ namespace pan
      * <ol>
      * <li>Replacing illegal characters with '_'.
      * <li>Ensure the resulting string is UTF8-safe
+     * <li>This function assumes the input is UTF8 since gmime uses UTF8 interface.
+     * <li>Return value must be g_free'd.
      * </ol>
      */
     std::string sanitize (const StringView& filename);
