@@ -53,6 +53,8 @@ using namespace pan;
 ****
 ***/
 
+/// TODO : replace g_atexit (deprecated)!!!
+
 namespace
 {
 
@@ -668,6 +670,21 @@ namespace
     gtk_text_buffer_apply_tag_by_name (buffer, tag, &mark_start, &mark_end);
   }
 
+  void
+  show_signature (GtkTextBuffer      * buffer,
+                    GtkTextMark        * mark,
+                    std::string        & body,
+                    bool                show)
+  {
+    GtkTextTagTable * tags (gtk_text_buffer_get_tag_table (buffer));
+    if (tags)
+    {
+      GtkTextTag * sig_tag (gtk_text_tag_table_lookup (tags, "signature"));
+      if (sig_tag)
+        g_object_set (sig_tag, "invisible", !show, NULL);
+    }
+  }
+
   void
   replace_emoticon_text_with_pixbuf (GtkTextBuffer      * buffer,
                                      GtkTextMark        * mark,
@@ -713,6 +730,7 @@ namespace
                              const StringView    & body_in,
                              bool                  mute_quotes,
                              bool                  show_smilies,
+                             bool                  show_sig,
                              bool                  do_markup,
                              bool                  do_urls)
   {
@@ -852,6 +870,8 @@ namespace
         replace_emoticon_text_with_pixbuf (buffer, mark, body, it->first, it->second);
     }
 
+    show_signature (buffer, mark, body, show_sig);
+
     gtk_text_buffer_delete_mark (buffer, mark);
   }
 
@@ -999,7 +1019,8 @@ BodyPane :: append_part (GMimeObject * parent, GMimeObject * obj, GtkAllocation
     const bool do_smilies (_prefs.get_flag ("show-smilies-as-graphics", true));
     const bool do_markup (_prefs.get_flag ("show-text-markup", true));
     const bool do_urls (_prefs.get_flag ("highlight-urls", true));
-    append_text_buffer_nolock (&_tm, _buffer, str, do_mute, do_smilies, do_markup, do_urls);
+    const bool do_sig(_prefs.get_flag ("show-article-sig", true));
+    append_text_buffer_nolock (&_tm, _buffer, str, do_mute, do_smilies, do_sig, do_markup, do_urls);
     is_done = true;
   }
 
@@ -1217,26 +1238,6 @@ BodyPane :: refresh ()
   set_text_from_message (_message);
 }
 
-namespace
-{
-
-  /** Separates user id into name and email address */
-  std::pair<std::string,std::string> get_email_address(std::string& s)
-  {
-    std::pair<std::string,std::string> ret;
-    size_t in = s.find("<");
-    size_t out = s.find(">");
-    if (in == std::string::npos ||
-        out == std::string::npos)
-      return ret;
-
-    ret.first = s.substr(0,in-1);
-    ret.second = s.substr (in+1,out-in-1);
-
-    return ret;
-  }
-}
-
 #ifdef HAVE_GMIME_CRYPTO
 gboolean
 BodyPane :: on_verbose_tooltip_cb(GtkWidget  *widget,
@@ -1292,6 +1293,8 @@ BodyPane :: set_article (const Article& a)
 
   refresh ();
 
+  set_cleared(false);
+
   _data.mark_read (_article);
 }
 
@@ -1302,6 +1305,8 @@ BodyPane :: clear ()
     g_object_unref (_message);
   _message = 0;
 
+  set_cleared(true);
+
   refresh ();
 }
 
@@ -1667,7 +1672,8 @@ BodyPane :: BodyPane (Data& data, ArticleCache& cache, Prefs& prefs, GroupPrefs
 //  _gpgerr(GPG_DECODE),
 #endif
   _attachments(0),
-  _current_attachment(0)
+  _current_attachment(0),
+  _cleared (true)
 {
 
   GtkWidget * w, * l, * hbox;
@@ -1791,6 +1797,9 @@ BodyPane :: ~BodyPane ()
 
   foreach (std::set<char*>, _attach_names, it)
     g_free(*it);
+
+  // store last opened message in prefs
+  _prefs.set_string("last-opened-msg", get_cleared() ? "" : get_message_id().to_view());
 }
 
 
@@ -2068,7 +2077,9 @@ BodyPane :: on_prefs_flag_changed (const StringView& key, bool value G_GNUC_UNUS
       (key=="mute-signature") ||
       (key=="show-smilies-as-graphics") || (key=="show-all-headers") ||
       (key=="size-pictures-to-fit") || (key=="show-text-markup") ||
-      (key=="highlight-urls") )
+      (key=="highlight-urls") ||
+      (key=="show-article-sig")
+     )
     refresh ();
 }
 
