@@ -97,13 +97,15 @@ namespace pan
     public:
       void set_character_encoding (const char * character_encoding);
 
+    public:
+      void set_text_from_message (GMimeMessage*);
+
     private:
       void refresh ();
       void refresh_fonts ();
       void refresh_colors ();
       bool read_more_or_less (bool more);
       char* body_to_utf8 (GMimePart*);
-      void set_text_from_message (GMimeMessage*);
       void append_part (GMimeObject*, GMimeObject*, GtkAllocation*);
       static gboolean expander_activated_idle (gpointer self);
       static void expander_activated_cb (GtkExpander*, gpointer self);
@@ -159,6 +161,12 @@ namespace pan
       std::set<char*> _attach_names;
       MenuSelection _selection;
 
+      bool _cleared;
+
+    public:
+      void set_cleared(bool val) { _cleared = val; }
+      bool get_cleared() { return _cleared; }
+
     public:
       const char* _current_attachment;
 
