@@ -708,13 +708,26 @@ namespace
       g_snprintf (buf, sizeof(buf), " (%lu)", unread);
       group_name += buf;
     }
-    //if (unread || total)
-      //if (unread)
-      //  g_snprintf (buf, sizeof(buf), _(" (%lu of %lu)"), unread, total);
-      //else
+
+
+
+
+    std::string fg_col(pane->get_group_prefs().get_group_color_str(name));
+    if (fg_col.empty())
+      fg_col = pane->get_prefs().get_color_str_wo_fallback("group-pane-fg-color");
+
+    if (fg_col.empty())
+    {
+      GdkColor def_fg;
+      GtkStyle *style = gtk_rc_get_style(pane->root());
+      if(!gtk_style_lookup_color(style, "text_color", &def_fg))
+        gdk_color_parse("black", &def_fg);
+      fg_col = GroupPrefs::color_to_string(def_fg);
+    }
+
     g_object_set (renderer, "text", group_name.c_str(),
                             "weight", (!is_g || unread ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL),
-                            "foreground", pane->get_group_prefs().get_group_color_str(name).c_str(),
+                            "foreground", fg_col.c_str(),
                             NULL);
   }
 }
@@ -785,6 +798,18 @@ GroupPane :: find_next_subscribed_group (bool unread_only)
   }
 }
 
+void
+GroupPane :: read_group (const StringView& groupname)
+{
+    GtkTreeView * view (GTK_TREE_VIEW (_tree_view));
+    PanTreeStore * tree (PAN_TREE_STORE(gtk_tree_view_get_model(view)));
+    GtkTreeIter iter;
+//    gtk_tree_model_iter_nth_child (model, &iter, 0, 0);
+    const MyRow* row = find_row (groupname);
+    iter = tree->get_iter (row);
+    read_group(gtk_tree_model_get_path(gtk_tree_view_get_model(view), &iter));
+}
+
 void
 GroupPane :: read_group (GtkTreePath * path)
 {
@@ -1011,5 +1036,6 @@ void
 GroupPane :: on_prefs_color_changed (const StringView& key, const GdkColor&)
 {
   if (key == "group-color")
+    refresh_font ();
     refresh_dirty_groups ();
 }
