@@ -177,6 +177,34 @@ void GUI :: show_task_window_cb (GtkWidget *, gpointer gui_gpointer)
   static_cast<GUI*>(gui_gpointer)->activate_action ("show-task-window");
 }
 
+void
+GUI :: root_realized_cb (GtkWidget*, gpointer self_gpointer)
+{
+  GUI* gui (static_cast<GUI*>(self_gpointer));
+
+  StringView last_group = gui->_prefs.get_string("last-visited-group", "");
+  if (!last_group.empty())
+  {
+    gui->_group_pane->read_group(last_group.str);
+  }
+
+  // TODO if article is not cached, load with a taskarticle action!
+  StringView last_msg = gui->_prefs.get_string("last-opened-msg", "");
+  if (!last_msg.empty())
+  {
+    mid_sequence_t files;
+    files.push_back(last_msg);
+    GMimeMessage* msg;
+#ifdef HAVE_GMIME_CRYPTO
+    GPGDecErr err;
+    msg = gui->_cache.get_message(files,err);
+#else
+    msg = gui->_cache.get_message(files);
+#endif
+    gui->_body_pane->set_text_from_message(msg);
+
+  }
+}
 
 GUI :: GUI (Data& data, Queue& queue, Prefs& prefs, GroupPrefs& group_prefs):
   _data (data),
@@ -352,6 +380,10 @@ GUI :: GUI (Data& data, Queue& queue, Prefs& prefs, GroupPrefs& group_prefs):
 #ifdef HAVE_GMIME_CRYPTO
   init_gpg();
 #endif
+
+  g_signal_connect (_root, "realize", G_CALLBACK(root_realized_cb), this);
+
+
 }
 
 namespace
@@ -642,7 +674,6 @@ void GUI :: do_read_or_save_articles ()
     do_read_selected_article();
 }
 
-
 void GUI :: do_save_articles_to_nzb ()
 {
 
@@ -977,8 +1008,7 @@ void GUI :: do_download_selected_article ()
 void GUI :: do_clear_header_pane ()
 {
   gtk_window_set_title (get_window(_root), _("Pan"));
-  _header_pane->set_group (Quark());
-
+  _header_pane->clear ();
 }
 
 void GUI :: do_clear_body_pane ()
@@ -1093,7 +1123,7 @@ void GUI :: prefs_dialog_destroyed (GtkWidget *)
 
 void GUI :: do_show_servers_dialog ()
 {
-  GtkWidget * w = server_list_dialog_new (_data, _queue, get_window(_root));
+  GtkWidget * w = server_list_dialog_new (_data, _queue, _prefs, get_window(_root));
   gtk_widget_show_all (w);
   g_signal_connect (w, "destroy", G_CALLBACK(server_list_dialog_destroyed_cb), this);
 }
@@ -1102,7 +1132,7 @@ void GUI :: do_show_servers_dialog ()
 void GUI :: do_show_sec_dialog ()
 {
 #ifdef HAVE_GNUTLS
-  GtkWidget * w = sec_dialog_new (_data, _queue, get_window(_root));
+  GtkWidget * w = sec_dialog_new (_data, _queue, _prefs, get_window(_root));
   g_signal_connect (w, "destroy", G_CALLBACK(sec_dialog_destroyed_cb), this);
   gtk_widget_show_all (w);
 #endif
@@ -2291,11 +2321,18 @@ void
 GUI :: do_show_cert_failed_dialog(VerifyData* data)
 {
   debug("do show cert failed dialog");
-  const VerifyData& d(*data);
+  VerifyData& d(*data);
+  bool delete_cert = false;
   if (GUI::confirm_accept_new_cert_dialog(get_window(_root),d.cert,d.server))
+  {
     if (!_certstore.add(d.cert, d.server))
+    {
       Log::add_urgent_va("Error adding certificate of server '%s' to Certificate Store",d.server.c_str());
+      delete_cert = true;
+    }
+  }
 
+  if (delete_cert) d.deinit_cert();
   delete data;
 }
 
@@ -2320,7 +2357,6 @@ GUI :: on_verify_cert_failed(gnutls_x509_crt_t cert, std::string server, int nr)
   data->nr = nr;
   data->gui = this;
   g_idle_add(show_cert_failed_cb, data);
-
 }
 
 void
