@@ -483,6 +483,20 @@ HeaderPane :: column_compare_func (GtkTreeModel  * model,
   return ret;
 }
 
+void
+HeaderPane :: sort_column_changed_cb (GtkTreeSortable *sortable,
+                                      gpointer         user_data)
+{
+
+  HeaderPane * self(static_cast<HeaderPane*>(user_data));
+
+  const articles_set old_selection (self->get_full_selection ());
+
+  if (!old_selection.empty())
+    self->select_message_id ((*(old_selection.begin()))->message_id);
+
+}
+
 PanTreeStore*
 HeaderPane :: build_model (const Quark               & group,
                            Data::ArticleTree         * atree,
@@ -531,6 +545,7 @@ namespace
 void
 HeaderPane :: rebuild ()
 {
+
   quarks_t selectme;
   if (1) {
     const articles_set old_selection (get_full_selection ());
@@ -554,6 +569,9 @@ HeaderPane :: rebuild ()
   gtk_tree_view_set_model (view, model);
   g_object_unref (G_OBJECT(_tree_store)); // store is deleted w/view
 
+  // add signal here to avoid loop
+  g_signal_connect (GTK_TREE_SORTABLE(_tree_store), "sort-column-changed", G_CALLBACK(sort_column_changed_cb), this);
+
   if (_prefs.get_flag ("expand-threads-when-entering-group", false))
     gtk_tree_view_expand_all (view);
 
@@ -564,6 +582,9 @@ HeaderPane :: rebuild ()
 bool
 HeaderPane :: set_group (const Quark& new_group)
 {
+
+  set_cleared(new_group.empty());
+
   const Quark old_group (_group);
   bool change (old_group != new_group);
 
@@ -671,6 +692,7 @@ namespace
 void
 HeaderPane :: select_message_id (const Quark& mid, bool do_scroll)
 {
+
   HeaderPane::Row * row = get_row (mid);
   GtkTreePath * path (_tree_store->get_path(row));
   GtkTreeView * view (GTK_TREE_VIEW(_tree_view));
@@ -1742,11 +1764,12 @@ HeaderPane :: ~HeaderPane ()
   }
   g_list_free (columns);
 
+  _prefs.set_string("last-visited-group", get_cleared() ? "" : _group.to_view());
   set_group (Quark());
 
+
   for (guint i=0; i<ICON_QTY; ++i)
     g_object_unref (G_OBJECT(_icons[i].pixbuf));
-
 }
 
 GtkWidget*
@@ -1793,7 +1816,7 @@ HeaderPane :: create_filter_entry ()
 }
 
 void
-HeaderPane :: on_selection_changed (GtkTreeSelection*, gpointer self_gpointer)
+HeaderPane :: on_selection_changed (GtkTreeSelection* sel, gpointer self_gpointer)
 {
   HeaderPane * self (static_cast<HeaderPane*>(self_gpointer));
 
@@ -1857,7 +1880,8 @@ HeaderPane :: HeaderPane (ActionManager       & action_manager,
   _tree_store (0),
   _selection_changed_idle_tag (0),
   _cache (cache),
-  _gui (gui)
+  _gui (gui),
+  _cleared (true)
 {
   // init the icons
   for (guint i=0; i<ICON_QTY; ++i)
@@ -1883,7 +1907,6 @@ HeaderPane :: HeaderPane (ActionManager       & action_manager,
   g_signal_connect (sel, "changed", G_CALLBACK(on_selection_changed), this);
   on_selection_changed (sel, this);
 
-
   g_signal_connect (w, "button-release-event", G_CALLBACK(on_button_pressed), this);
   g_signal_connect (w, "button-press-event", G_CALLBACK(on_button_pressed), this);
 
