@@ -1,8 +1,10 @@
-const char * fallback_post_ui = 
+// "      <menuitem action='wrapselected' />\n"  doesnt exist yet, so deactivated for now....
+const char * fallback_post_ui =
 "<ui>\n"
 "  <menubar name='post'>\n"
 "    <menu action='file-menu'>\n"
 "      <menuitem action='post-article' />\n"
+"      <menuitem action ='post-and-save-articles'  />\n"
 "      <separator />\n"
 "      <menuitem action='save-draft' />\n"
 "      <menuitem action='open-draft' />\n"
@@ -15,14 +17,16 @@ const char * fallback_post_ui =
 "      <menuitem action='paste' />\n"
 "      <menuitem action='rot13' />\n"
 "      <separator />\n"
+"      <menuitem action='set-encoding' />\n"
 "      <menuitem action='set-charset' />\n"
 "      <menuitem action='remember-charset' />\n"
 "      <separator />\n"
+"      <menuitem action='master-reply' />\n"
+"      <separator />\n"
 "      <menuitem action='run-editor' />\n"
 "      <menuitem action='always-run-editor' />\n"
 "      <separator />\n"
 "      <menuitem action='wrap' />\n"
-"      <menuitem action='wrapselected' />\n"
 "      <menuitem action='spellcheck' />\n"
 "      <separator />\n"
 "      <menuitem action='manage-profiles' />\n"
@@ -31,6 +35,7 @@ const char * fallback_post_ui =
 "\n"
 "  <toolbar name='post-toolbar'>\n"
 "    <toolitem action='post-article' />\n"
+"    <toolitem action='post-and-save-articles' />\n"
 "    <separator />\n"
 "    <toolitem action='save-draft' />\n"
 "    <toolitem action='open-draft' />\n"
@@ -39,6 +44,21 @@ const char * fallback_post_ui =
 "    <separator />\n"
 "    <toolitem action='rot13' />\n"
 "    <toolitem action='run-editor' />\n"
+"    <separator />\n"
+"    <toolitem action='add-files' />\n"
 "  </toolbar>\n"
 "\n"
+"  <popup name='filequeue-popup'>\n"
+"    <menuitem action='remove-files' />\n"
+"    <menuitem action='clear-list' />\n"
+"    <separator />\n"
+"    <menuitem action='select-parts' />\n"
+"    <separator />\n"
+"    <menuitem action='move-up' />\n"
+"    <menuitem action='move-down' />\n"
+"    <separator />\n"
+"    <menuitem action='move-top' />\n"
+"    <menuitem action='move-bottom' />\n"
+"  </popup>\n"
+"\n"
 "</ui>\n";
