@@ -20,14 +20,14 @@
 #ifndef __Progress_View_h__
 #define __Progress_View_h__
 
-#include <gtk/gtkwidget.h>
+#include "gtk-compat.h"
 #include <pan/general/progress.h>
 
 namespace pan
 {
   /**
    * GtkProgressBar representations of general::Progress objects.
-   * 
+   *
    * These are used at the bottom of Pan's main window to show
    * the status of running Task objects.
    *
@@ -48,7 +48,7 @@ namespace pan
       virtual void on_progress_step (Progress&, int percentage);
       virtual void on_progress_status (Progress&, const StringView&);
       virtual void on_progress_error (Progress&, const StringView&);
-      virtual void on_progress_finished (Progress&, int status) { }
+      virtual void on_progress_finished (Progress&, int) { }
 
     private:
       void update_text_soon ();
