@@ -56,6 +56,7 @@ namespace
   {
     Data& data;
     Queue& queue;
+    Prefs& prefs;
     Quark server;
     StringView cert;
     GtkWidget * dialog;
@@ -68,7 +69,7 @@ namespace
     GtkWidget * rank_combo;
     GtkWidget * ssl_combo;
     GtkWidget * always_trust_checkbox;
-    ServerEditDialog (Data& d, Queue& q): data(d), queue(q) {}
+    ServerEditDialog (Data& d, Queue& q, Prefs& p): data(d), queue(q), prefs(p) {}
   };
 
   void pan_entry_set_text (GtkWidget * w, const StringView& v)
@@ -107,7 +108,7 @@ namespace
   }
 
   void
-  edit_dialog_populate (Data&, const Quark& server, ServerEditDialog * d)
+  edit_dialog_populate (Data&, Prefs& prefs, const Quark& server, ServerEditDialog * d)
   {
     // sanity clause
     g_return_if_fail (d!=0);
@@ -120,7 +121,7 @@ namespace
     gchar* pass(NULL);
     if (!server.empty()) {
       d->data.get_server_addr (server, addr, port);
-      d->data.get_server_auth (server, user, pass);
+      d->data.get_server_auth (server, user, pass, prefs.get_flag("use-gnome-keyring",false));
       age = d->data.get_server_article_expiration_age (server);
       rank = d->data.get_server_rank (server);
       max_conn = d->data.get_server_limits (server);
@@ -130,7 +131,6 @@ namespace
     }
 
     pan_entry_set_text (d->address_entry, addr);
-    pan_spin_button_set (d->port_spin, port);
     pan_spin_button_set (d->connection_limit_spin, max_conn);
     pan_entry_set_text (d->auth_username_entry, user);
     pan_entry_set_text (d->auth_password_entry, pass);
@@ -176,6 +176,8 @@ namespace
 
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(d->always_trust_checkbox), trust);
 #endif
+
+    pan_spin_button_set (d->port_spin, port);
   }
 
   void
@@ -229,7 +231,7 @@ namespace
                                                     GTK_DIALOG_DESTROY_WITH_PARENT,
                                                     GTK_MESSAGE_ERROR,
                                                     GTK_BUTTONS_CLOSE,
-                                                    err_msg));
+                                                    "%s",err_msg));
         g_signal_connect_swapped (dialog, "response", G_CALLBACK(gtk_widget_destroy), dialog);
         gtk_widget_show (dialog);
         destroy = false;
@@ -237,14 +239,16 @@ namespace
         if (d->server.empty())
           d->server = d->data.add_new_server ();
         d->data.set_server_addr (d->server, addr, port);
-        d->data.set_server_auth (d->server, user, pass);
+        d->data.set_server_auth (d->server, user, pass, d->prefs.get_flag("use-gnome-keyring",false));
         d->data.set_server_limits (d->server, max_conn);
         d->data.set_server_article_expiration_age (d->server, age);
         d->data.set_server_rank (d->server, rank);
         d->data.set_server_ssl_support(d->server, ssl);
         d->data.set_server_cert(d->server,cert);
         d->data.set_server_trust(d->server,trust);
+
         d->data.save_server_info(d->server);
+
         d->queue.upkeep ();
       }
     }
@@ -287,9 +291,9 @@ pan :: import_sec_from_disk_dialog_new (Data& data, Queue& queue, GtkWindow * wi
 }
 
 GtkWidget*
-pan :: server_edit_dialog_new (Data& data, Queue& queue, GtkWindow * window, const Quark& server)
+pan :: server_edit_dialog_new (Data& data, Queue& queue, Prefs& prefs, GtkWindow * window, const Quark& server)
 {
-  ServerEditDialog * d (new ServerEditDialog (data, queue));
+  ServerEditDialog * d (new ServerEditDialog (data, queue, prefs));
 
   // create the dialog
   char * title = g_strdup_printf ("Pan: %s", server.empty() ? _("Add a Server") : _("Edit a Server's Settings"));
@@ -436,7 +440,7 @@ pan :: server_edit_dialog_new (Data& data, Queue& queue, GtkWindow * window, con
 #endif
 
   d->server = server;
-  edit_dialog_populate (data, server, d);
+  edit_dialog_populate (data, prefs, server, d);
   gtk_widget_show_all (d->dialog);
   return d->dialog;
 }
@@ -478,12 +482,13 @@ namespace
   {
     Data& data;
     Queue& queue;
+    Prefs& prefs;
     GtkWidget * server_tree_view;
     GtkWidget * dialog;
     GtkListStore * servers_store;
     GtkWidget * remove_button;
     GtkWidget * edit_button;
-    ServerListDialog (Data& d, Queue& q): data(d), queue(q) {}
+    ServerListDialog (Data& d, Queue& q, Prefs& p): data(d), queue(q), prefs(p) {}
   };
 
 
@@ -637,7 +642,7 @@ namespace
     const Quark empty_quark;
     GtkWidget * list_dialog = GTK_WIDGET (user_data);
     ServerListDialog * d = (ServerListDialog*) g_object_get_data (G_OBJECT(list_dialog), "dialog");
-    GtkWidget * edit_dialog = server_edit_dialog_new (d->data, d->queue, GTK_WINDOW(list_dialog), empty_quark);
+    GtkWidget * edit_dialog = server_edit_dialog_new (d->data, d->queue, d->prefs, GTK_WINDOW(list_dialog), empty_quark);
     g_signal_connect (edit_dialog, "destroy", G_CALLBACK(server_edit_dialog_destroy_cb), list_dialog);
     gtk_widget_show_all (edit_dialog);
   }
@@ -649,7 +654,7 @@ namespace
     ServerListDialog * d = (ServerListDialog*) g_object_get_data (G_OBJECT(list_dialog), "dialog");
     Quark selected_server (get_selected_server (d));
     if (!selected_server.empty()) {
-      GtkWidget * edit_dialog = server_edit_dialog_new (d->data, d->queue, GTK_WINDOW(list_dialog), selected_server);
+      GtkWidget * edit_dialog = server_edit_dialog_new (d->data, d->queue, d->prefs, GTK_WINDOW(list_dialog), selected_server);
       g_signal_connect (GTK_OBJECT(edit_dialog), "destroy", G_CALLBACK(server_edit_dialog_destroy_cb), list_dialog);
       gtk_widget_show_all (edit_dialog);
     }
@@ -692,15 +697,20 @@ namespace
       const gnutls_x509_crt_t cert (store.get_cert_to_server(selected_server));
       if (cert)
       {
-        pretty_print_x509(buf,sizeof(buf),addr, cert,false);
+        pretty_print_x509(buf,sizeof(buf),addr, cert, false);
         if (!buf) g_snprintf(buf,sizeof(buf), "%s", _("No information available.")) ;
-        GtkWidget * w = gtk_message_dialog_new_with_markup (
+
+        GtkWidget * w = gtk_message_dialog_new (
         0,
-        GTK_DIALOG_MODAL,
+        GtkDialogFlags(GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT),
         GTK_MESSAGE_INFO,
-        GTK_BUTTONS_CLOSE, buf);
+        GTK_BUTTONS_CLOSE, NULL);
+
+        HIG :: message_dialog_set_text (GTK_MESSAGE_DIALOG(w), buf, NULL);
+
         g_snprintf(buf,sizeof(buf), _("Server Certificate for '%s'"), addr.c_str());
         gtk_window_set_title(GTK_WINDOW(w), buf);
+
         gtk_widget_show_all (w);
         g_signal_connect_swapped (w, "response", G_CALLBACK (gtk_widget_destroy), w);
       }
@@ -819,9 +829,9 @@ namespace
 #endif
 
 GtkWidget*
-pan :: server_list_dialog_new (Data& data, Queue& queue, GtkWindow* parent)
+pan :: server_list_dialog_new (Data& data, Queue& queue, Prefs& prefs, GtkWindow* parent)
 {
-  ServerListDialog * d = new ServerListDialog (data, queue);
+  ServerListDialog * d = new ServerListDialog (data, queue, prefs);
 
   // dialog
   char * title = g_strdup_printf ("Pan: %s", _("Servers"));
@@ -908,10 +918,10 @@ pan :: render_cert_flag (GtkTreeViewColumn * ,
 
 
 GtkWidget*
-pan :: sec_dialog_new (Data& data, Queue& queue, GtkWindow* parent)
+pan :: sec_dialog_new (Data& data, Queue& queue, Prefs& prefs, GtkWindow* parent)
 {
 #ifdef HAVE_GNUTLS
-  ServerListDialog * d = new ServerListDialog (data, queue);
+  ServerListDialog * d = new ServerListDialog (data, queue, prefs);
 
   for (guint i=0; i<ICON_QTY; ++i)
     _icons[i].pixbuf = gdk_pixbuf_new_from_inline (-1, _icons[i].pixbuf_txt, FALSE, 0);
