@@ -20,6 +20,7 @@
 #ifndef __NNTP_h__
 #define __NNTP_h__
 
+#include <stdint.h>
 #include <deque>
 #include <pan/general/macros.h> // for UNUSED
 #include <pan/general/quark.h>
@@ -27,6 +28,52 @@
 #include <pan/tasks/health.h>
 #include <pan/tasks/socket.h>
 
+namespace
+{
+   enum
+   {
+      AUTH_REQUIRED              = 480,
+      AUTH_NEED_MORE             = 381,
+      AUTH_ACCEPTED              = 281,
+      AUTH_REJECTED              = 482,
+
+      SERVER_READY               = 200,
+      SERVER_READY_NO_POSTING    = 201,
+      SERVER_READY_STREAMING_OK  = 203,
+
+      GOODBYE                    = 205,
+
+      GROUP_RESPONSE             = 211,
+      GROUP_NONEXISTENT          = 411,
+
+      INFORMATION_FOLLOWS        = 215,
+
+      XOVER_FOLLOWS              = 224,
+      XOVER_NO_ARTICLES          = 420,
+
+      ARTICLE_FOLLOWS            = 220,
+
+      NEWGROUPS_FOLLOWS          = 231,
+
+      ARTICLE_POSTED_OK          = 240,
+      SEND_ARTICLE_NOW           = 340,
+      NO_POSTING                 = 440,
+      POSTING_FAILED             = 441,
+      DUPE_ARTICLE               = 435,  // sent additionally to 441
+
+      TOO_MANY_CONNECTIONS       = 400,
+
+      NO_GROUP_SELECTED          = 412,
+      NO_SUCH_ARTICLE_NUMBER     = 423,
+      NO_SUCH_ARTICLE            = 430,
+
+      ERROR_CMD_NOT_UNDERSTOOD   = 500,
+      ERROR_CMD_NOT_SUPPORTED    = 501,
+      NO_PERMISSION              = 502,
+      FEATURE_NOT_SUPPORTED      = 503
+   };
+}
+
 namespace pan
 {
   /**
@@ -62,7 +109,7 @@ namespace pan
          * lines for an ARTICLE command.
          */
         virtual void on_nntp_line  (NNTP               * nntp UNUSED,
-                                    const StringView   & line UNUSED) {}
+                                    const StringView   & line UNUSED)  {}
 
         /**
          * Called at the end of an NNTP command.  If the command was
@@ -79,14 +126,19 @@ namespace pan
                                     Health               health   UNUSED,
                                     const StringView   & response UNUSED) {}
 
+        virtual void on_xover_done  (NNTP               * nntp     UNUSED,
+                                    Health               health   UNUSED,
+                                    const StringView   & response UNUSED) {}
+
         /**
          * Called whenever an NNTP object sets the current group.
          */
         virtual void on_nntp_group (NNTP               * nntp          UNUSED,
                                     const Quark        & group         UNUSED,
                                     unsigned long        estimated_qty UNUSED,
-                                    unsigned long        low           UNUSED,
-                                    unsigned long        high          UNUSED) {}
+                                    uint64_t             low           UNUSED,
+                                    uint64_t             high          UNUSED) {}
+
        };
 
       public:
@@ -102,15 +154,24 @@ namespace pan
           _username(username),
           _password(password),
           _nntp_response_text(false)
-       {
-       }
+       {}
 
        virtual ~NNTP ()
-       {
-       }
+       {}
 
     public:
 
+      /* Internal only */
+      void get_group (const Quark& group);
+      void get_headers (const Quark & group, const char * message_id, Listener  * l);
+      void get_headers (const Quark & group, uint64_t article_number, Listener * l);
+      void get_body (const Quark & group, const char * message_id, Listener  * l);
+      void get_body (const Quark & group, uint64_t article_number, Listener * l);
+      /**
+       * Lists all available commands.
+       */
+      void help (Listener * l);
+
       /**
        * Executes a handshake command.
        *
@@ -129,8 +190,20 @@ namespace pan
        * command is successful or not.
        */
       void xover            (const Quark        & group,
-                             unsigned long        low,
-                             unsigned long        high,
+                             uint64_t             low,
+                             uint64_t             high,
+                             Listener           * l);
+      /**
+       * Executes an XOVER command: "XOVER" to count
+       * the xover numbers internally
+       *
+       * If successful, this will invoke Listener::on_nntp_line()
+       * for each article header line we get back.
+       *
+       * Listener::on_nntp_done() will be called whether the
+       * command is successful or not.
+       */
+      void xover_count_only (const Quark        & group,
                              Listener           * l);
 
       /**
@@ -170,7 +243,7 @@ namespace pan
        * to change groups.
        */
       void article          (const Quark        & group,
-                             unsigned long        article_number,
+                             uint64_t             article_number,
                              Listener           * l);
 
       /**
