@@ -37,10 +37,12 @@ Queue :: Queue (ServerInfo         & server_info,
                 TaskArchive        & archive,
                 SocketCreator      * socket_creator,
                 CertStore          & certstore,
+                Prefs              & prefs,
                 WorkerPool         & pool,
                 bool                 online,
                 int                  save_delay_secs):
   _server_info (server_info),
+  _prefs (prefs),
   _is_online (online),
   _socket_creator (socket_creator),
   _worker_pool (pool),
@@ -104,7 +106,7 @@ Queue :: get_pool (const Quark& servername)
   }
   else // have to build one
   {
-    pool = new NNTP_Pool (servername, _server_info, _socket_creator, _certstore);
+    pool = new NNTP_Pool (servername, _server_info, _prefs, _socket_creator, _certstore);
     pool->add_listener (this);
     _pools[servername] = pool;
   }
@@ -166,10 +168,6 @@ Queue :: upkeep ()
   foreach (std::set<Task*>, active, it)
     process_task (*it);
 
-  //upkeep on paused upload slots
-//  foreach (std::set<TaskUpload*>, _uploads, it)
-//    process_task (*it);
-
   // idle socket upkeep
   foreach (pools_t, _pools, it)
     it->second->idle_upkeep ();
@@ -325,7 +323,6 @@ Queue :: process_task (Task * task)
 //    TaskArticle* t2 = dynamic_cast<TaskArticle*>(task);
 //    if (t2)
 //      give_task_a_download_slot(t2);
-
   }
   else if (state._work == Task::NEED_DECODER)
   {
@@ -548,6 +545,12 @@ Queue :: stop_tasks (const tasks_t& tasks)
     if (_tasks.index_of (task) != -1) {
       _stopped.insert (task);
       process_task (task);
+
+      TaskArticle* ta = dynamic_cast<TaskArticle*>(*it);
+      if (ta)
+      {
+        ta->set_start_paused(true);
+      }
     }
   }
 }
@@ -560,6 +563,12 @@ Queue :: restart_tasks (const tasks_t& tasks)
     if (_tasks.index_of(task) != -1) {
       _stopped.erase (task);
       process_task (task);
+
+      TaskArticle* ta = dynamic_cast<TaskArticle*>(*it);
+      if (ta)
+      {
+        ta->set_start_paused(false);
+      }
     }
   }
 }
@@ -575,10 +584,17 @@ Queue :: add_task (Task * task, AddMode mode)
 void
 Queue :: add_tasks (const tasks_t& tasks, AddMode mode)
 {
+
   foreach_const (tasks_t, tasks, it) {
     TaskArticle * ta (dynamic_cast<TaskArticle*>(*it));
     if (ta)
+    {
       _mids.insert (ta->get_article().message_id);
+      if (ta->start_paused())
+      {
+        _stopped.insert(*it);
+      }
+    }
   }
 
   if (mode == TOP)
@@ -588,7 +604,7 @@ Queue :: add_tasks (const tasks_t& tasks, AddMode mode)
   else
     _tasks.add (tasks);
 
-  // asdf
+  // process all new tasks
   tasks_t tmp (tasks);
   foreach (tasks_t, tmp, it)
     process_task (*it);
