@@ -19,6 +19,7 @@
 
 #include <config.h>
 #include <cassert>
+#include <cstdlib>
 #include <pan/general/debug.h>
 #include <pan/general/messages.h>
 #include <pan/general/string-view.h>
@@ -38,14 +39,13 @@ ScriptedSocket :: ~ScriptedSocket ()
 }
 
 bool
-ScriptedSocket :: open (const StringView& address, int port)
+ScriptedSocket :: open (const StringView& address UNUSED, int port UNUSED)
 {
   // FIXME: always succeeds right now; should have an ar in ctor to make it fail
   return true;
 }
 
-void
-ScriptedSocket :: write_command (const StringView& chars, Listener * l)
+void ScriptedSocket :: write_command (const StringView& chars, Listener * l)
 {
    if (_script.empty()) {
       debug ("UNEXPECTED [" << chars << ']');
