@@ -66,7 +66,7 @@ namespace
   {
     std::string r;
     quarks_t groups;
-    int cnt(1);
+    size_t cnt(1);
     foreach_const (Xref, a.xref, xit)
     {
       r += xit->group.to_string();
@@ -433,6 +433,8 @@ TaskUpload :: on_worker_done (bool cancelled)
         _needed.clear(); //update_work will then set the status to complete
     }
 
+    _state.set_health(_encoder->health);
+
     if (!_encoder->log_severe.empty())
       _state.set_health (ERR_LOCAL);
     else
